# Rundeck

A role for deploying Rundeck.

## Requirements
Ansible host:
* [Ansible](http://docs.ansible.com/ansible/) 2.2.1.0 or newer

Managed hosts:
* `docker` installed on each host

## Role Variables

### General options
* `rundeck_root_url` - url of Rundeck application, should contain protocol and port 
(e.g. `https://rundeck.domain.com:8443`)
* `rundeck_proxied` - inform if rundeck is exposed using proxy
* *(optional)* `rundeck_bind_ip` - the IP address of the host machine, to which the Rundeck container will bind
(default: `"0.0.0.0"`, bind to all interfaces) 
* *(optional)* `rundeck_bind_port` - the port of the host machine, to which the Rundeck container will bind
(default: `4440`)        
* *(optional)* `rundeck_data_path` - absolute path to the directory where Rundeck and its database will store data 
(default: `"/opt/rundeck"`)
* *(optional)* `rundeck_service_name` - name of the *systemd* service with Rundeck and its dependencies 
(default: `"rundeck"`)
* *(optional)* `rundeck_storage_provider` - Rundeck storage provider (default: `file`)
 
### Authentication
* `rundeck_admin_password` - password for the `admin` user in Rundeck.
* `rundeck_database_password` - password for the database user; the database user's name is set
to `rundeck` and cannot be changed

### Users configuration
The `users` action creates users as defined in the `rundeck_users` variable. This variable should be a list of
dictionaries with the following keys:
* `name` - user name (for logging in to Rundeck)
* `password` - user password
* `roles` - a list of user roles. Role support only default roles defined in rundeck: `admin`, `user`, `architect`, 
`deploy`, `build`. 
 
**WARNING** All users have access to all projects at this moment.

Example:
```yaml
rundeck_users:
  - name: "admin"
    password: "testsecret"
    roles:
      - "user"
      - "admin"
      - "architect"
      - "deploy"
      - "build"
  - name: "user"
    password: "testtest"
    roles:
      - "user"
      - "architect"
      - "deploy"
      - "build"
```

More about configuring access policies:
* [authenticating users](http://rundeck.org/2.7.3/administration/authenticating-users.html)
* [access control policy](http://rundeck.org/2.7.3/administration/access-control-policy.html)

### Projects configuration
* `rundeck_projects_definiton` - a list of projects definitions; each definition should be a
  dictionary in the following format:
    * `name` - the name of the project
    * `credentials` - at least one private key should be specified and declared as `default_key`
      for each project; the definition of each key should contain:
        * `name` - the name to store in the key storage
        * `content` - the raw content of the key or a plain password
        * `type` - the type of the key; the possible values are:
            * `PRIVATE` (when the content is a private key)
            * `PUBLIC` (when the content is a public key)
            * `PASSWORD`
    * `default_key` - the name of one of the keys specified in the `credentials` field; this key will be
      used by default for all jobs in the project
  
Example:
```yaml
rundeck_projects_definiton:
  - name: "backup"
    credentials:
      - name: "secret_rsa"
        content: "{{ lookup('file','/opt/some-secret-rsa') }}"
        type: PRIVATE
      - name: "secret_rsa.pub"
        content: "{{ lookup('file','/opt/some-secret-rsa.pub') }}"
        type: PUBLIC
      - name: "password"
        content: "secret_password"
        type: PASSWORD
    default_key: "secret_rsa"
```

## Role Actions
* `deploy` - deploys Rundeck on a host
* `projects` - configure projects in Rundeck
* `users` - create users in Rundeck

## Dependencies
Roles:
* `docker` - this role uses docker `service_base` action, so the 
[`docker`](https://projects.task.gda.pl/ansible-roles/docker) role must be accessible

## Example Playbook

### Deploying Rundeck
```yml
---
- name: "Deploy Rundeck"
  hosts: rundeck
  roles:
    - role: "rundeck"
      action: "deploy"
```

### Configuring Rundeck projects
```yml
---
- name: "configure rundeck projects"
  hosts: "rundeck"
  roles:
    - role: "rundeck"
      action: "projects"
```

### Users configuration
It is recommended to use this action in a separate playbook.   
[Users configuration](#users-configuration) should be provided by the `--extra-vars` parameter.

```yml
---
- name: "Create Rundeck users"
  hosts: rundeck
  roles:
    - role: "rundeck"
      action: "users"
```

## License
MIT

## Author Information
Academic Computer Centre in Gdansk (CI TASK)

http://task.gda.pl/

## Additional Resources
* [Rundeck official page](http://rundeck.org/)
* [Rundeck container](https://hub.docker.com/r/jordan/rundeck/)
* [Docker Ansible role](https://projects.task.gda.pl/ansible-roles/docker)
